@@ -6,5 +6,5 @@
 # the Apache License 2.0.  The full license can be found in the LICENSE file.
 #
 
-from .np import deconstruct_numpy, make_null_mask   # noqa: F401
-from .pd import deconstruct_pandas  # noqa: F401
+from .np import deconstruct_numpy, make_null_mask
+from .pd import deconstruct_pandas
